==> download.php?FileName=terralib-5.4.0.zip: share/terralib/translations/terralib_mod_qt_plugins_datasource_wfs_pt_br.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>WFSConnectorDialogForm</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/ui/WFSConnectorDialogForm.ui" line="14"/>
        <source>WFS Connector</source>
        <translation>Conector WFS</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/ui/WFSConnectorDialogForm.ui" line="39"/>
        <source>WFS - Web Feature Service</source>
        <translation>WFS - Web Feature Service</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/ui/WFSConnectorDialogForm.ui" line="51"/>
        <source>Service Address</source>
        <translation>Endereço do Serviço</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/ui/WFSConnectorDialogForm.ui" line="70"/>
        <source>Data Source Title</source>
        <translation>Título da Fonte de Dados</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/ui/WFSConnectorDialogForm.ui" line="80"/>
        <source>Data Source Description</source>
        <translation>Descrição da Fonte de Dados</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/ui/WFSConnectorDialogForm.ui" line="99"/>
        <source>A more detailed description about the data source</source>
        <translation>Uma descrição mais detalhada sobre a fonte de dados</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/ui/WFSConnectorDialogForm.ui" line="115"/>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/ui/WFSConnectorDialogForm.ui" line="137"/>
        <source>&amp;Test</source>
        <translation>&amp;Teste</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/ui/WFSConnectorDialogForm.ui" line="144"/>
        <source>&amp;Open</source>
        <translation>&amp;Abrir</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/ui/WFSConnectorDialogForm.ui" line="151"/>
        <source>&amp;Close</source>
        <translation>&amp;Close</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::wfs::WFSConnector</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/WFSConnector.cpp" line="70"/>
        <source>TerraLib Qt Components</source>
        <translation>Componentes TerraLib Qt</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/WFSConnector.cpp" line="70"/>
        <source>The WFS data access driver not support creation operation.</source>
        <translation>O driver de acesso a dados WFS não suporta operação de criação.</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::wfs::WFSConnectorDialog</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/WFSConnectorDialog.cpp" line="140"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/WFSConnectorDialog.cpp" line="146"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/WFSConnectorDialog.cpp" line="170"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/WFSConnectorDialog.cpp" line="178"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/WFSConnectorDialog.cpp" line="184"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/WFSConnectorDialog.cpp" line="192"/>
        <source>TerraLib Qt Components</source>
        <translation>Componentes TerraLib Qt</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/WFSConnectorDialog.cpp" line="147"/>
        <source>Unknown error while opening WFS data source!</source>
        <translation>Erro desconhecido durante abertura da fonte de dados WFS !</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/WFSConnectorDialog.cpp" line="171"/>
        <source>Data source is ok!</source>
        <translation>Fonte de dados está ok !</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/WFSConnectorDialog.cpp" line="185"/>
        <source>Unknown error while testing WFS data source!</source>
        <translation>Erro desconhecido durante teste na fonte de dados WFS !</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/WFSConnectorDialog.cpp" line="193"/>
        <source>Not implemented yet!
We will provide it soon!</source>
        <translation>Ainda não implementado!
Iremos fornecer em breve!</translation>
    </message>
</context>
</TS>

==> download.php?FileName=terralib-5.5.0.zip: share/terralib/translations/terralib_mod_qt_plugins_datasource_wfs_pt_br.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_BR">
<context>
    <name>WFSConnectorDialogForm</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/ui/WFSConnectorDialogForm.ui" line="14"/>
        <source>WFS Connector</source>
        <translation>Conector WFS</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/ui/WFSConnectorDialogForm.ui" line="39"/>
        <source>WFS - Web Feature Service</source>
        <translation>WFS - Web Feature Service</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/ui/WFSConnectorDialogForm.ui" line="51"/>
        <source>Service Address</source>
        <translation>Endereço do Serviço</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/ui/WFSConnectorDialogForm.ui" line="70"/>
        <source>Data Source Title</source>
        <translation>Título da Fonte de Dados</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/ui/WFSConnectorDialogForm.ui" line="80"/>
        <source>Data Source Description</source>
        <translation>Descrição da Fonte de Dados</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/ui/WFSConnectorDialogForm.ui" line="99"/>
        <source>A more detailed description about the data source</source>
        <translation>Uma descrição mais detalhada sobre a fonte de dados</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/ui/WFSConnectorDialogForm.ui" line="115"/>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/ui/WFSConnectorDialogForm.ui" line="137"/>
        <source>&amp;Test</source>
        <translation>&amp;Teste</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/ui/WFSConnectorDialogForm.ui" line="144"/>
        <source>&amp;Open</source>
        <translation>&amp;Abrir</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/ui/WFSConnectorDialogForm.ui" line="151"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::wfs::WFSConnector</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/WFSConnector.cpp" line="69"/>
        <source>TerraLib Qt Components</source>
        <translation>Componentes TerraLib Qt</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/WFSConnector.cpp" line="69"/>
        <source>The WFS data access driver not support creation operation.</source>
        <translation>O driver de acesso a dados WFS não suporta operação de criação.</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::wfs::WFSConnectorDialog</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/WFSConnectorDialog.cpp" line="140"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/WFSConnectorDialog.cpp" line="146"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/WFSConnectorDialog.cpp" line="170"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/WFSConnectorDialog.cpp" line="178"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/WFSConnectorDialog.cpp" line="184"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/WFSConnectorDialog.cpp" line="192"/>
        <source>TerraLib Qt Components</source>
        <translation>Componentes TerraLib Qt</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/WFSConnectorDialog.cpp" line="147"/>
        <source>Unknown error while opening WFS data source!</source>
        <translation>Erro desconhecido durante abertura da fonte de dados WFS !</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/WFSConnectorDialog.cpp" line="171"/>
        <source>Data source is ok!</source>
        <translation>Fonte de dados está ok !</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/WFSConnectorDialog.cpp" line="185"/>
        <source>Unknown error while testing WFS data source!</source>
        <translation>Erro desconhecido durante teste na fonte de dados WFS !</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wfs/WFSConnectorDialog.cpp" line="193"/>
        <source>Not implemented yet!
We will provide it soon!</source>
        <translation>Ainda não implementado!
Iremos fornecer em breve!</translation>
    </message>
</context>
</TS>
